@@ -2,7 +2,7 @@
 // detail/pop_options.hpp
 // ~~~~~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2017 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2019 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -24,7 +24,9 @@
 // Intel C++
 
 # if (__GNUC__ == 4 && __GNUC_MINOR__ >= 1) || (__GNUC__ > 4)
-#  pragma GCC visibility pop
+#  if !defined(BOOST_ASIO_DISABLE_VISIBILITY)
+#   pragma GCC visibility pop
+#  endif // !defined(BOOST_ASIO_DISABLE_VISIBILITY)
 # endif // (__GNUC__ == 4 && __GNUC_MINOR__ >= 1) || (__GNUC__ > 4)
 
 #elif defined(__clang__)
@@ -42,7 +44,9 @@
 # endif
 
 # if !defined(_WIN32) && !defined(__WIN32__) && !defined(WIN32)
-#  pragma GCC visibility pop
+#  if !defined(BOOST_ASIO_DISABLE_VISIBILITY)
+#   pragma GCC visibility pop
+#  endif // !defined(BOOST_ASIO_DISABLE_VISIBILITY)
 # endif // !defined(_WIN32) && !defined(__WIN32__) && !defined(WIN32)
 
 #elif defined(__GNUC__)
@@ -64,9 +68,15 @@
 # endif
 
 # if (__GNUC__ == 4 && __GNUC_MINOR__ >= 1) || (__GNUC__ > 4)
-#  pragma GCC visibility pop
+#  if !defined(BOOST_ASIO_DISABLE_VISIBILITY)
+#   pragma GCC visibility pop
+#  endif // !defined(BOOST_ASIO_DISABLE_VISIBILITY)
 # endif // (__GNUC__ == 4 && __GNUC_MINOR__ >= 1) || (__GNUC__ > 4)
 
+# if (__GNUC__ >= 7)
+#  pragma GCC diagnostic pop
+# endif // (__GNUC__ >= 7)
+
 #elif defined(__KCC)
 
 // Kai C++
